@@ -1,7 +1,7 @@
 package Email::Simple::Markdown;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: simple email creation with auto text and html multipart body
-$Email::Simple::Markdown::VERSION = '0.6.0';
+$Email::Simple::Markdown::VERSION = '0.7.0';
 use strict;
 use warnings;
 
@@ -121,21 +121,6 @@ sub with_markdown {
 
     $mail->content_type_set('multipart/alternative');
 
-    my $markdown = $body;
-
-    if( my $filter =  $self->markdown_filter ) {
-        local $_ = $markdown;
-        $filter->();
-        $markdown = $_;
-    }
-    
-    $markdown = $self->_markdown($markdown);
-    $markdown = '<style type="text/css">'
-              . $self->css
-              . '</style>'
-              . $markdown 
-        if $self->css;
-
     $mail->parts_set([
         Email::MIME->create(
             attributes => { 
@@ -150,13 +135,34 @@ sub with_markdown {
                 charset      => $self->markdown_charset,
                 encoding     => 'quoted-printable',
             },
-            body => $markdown,
+            body => $self->markdown_part,
         )
     ]);
 
     return Email::Abstract->new($mail);
 }
 
+sub markdown_part {
+    my $self = shift;
+
+    my $markdown = $self->body;
+
+    if( my $filter =  $self->markdown_filter ) {
+        local $_ = $markdown;
+        $filter->();
+        $markdown = $_;
+    }
+    
+    $markdown = $self->_markdown($markdown);
+    $markdown = '<style type="text/css">'
+              . $self->css
+              . '</style>'
+              . $markdown 
+        if $self->css;
+
+    return $markdown;
+}
+
 sub as_string { $_[0]->with_markdown->as_string }
 
 1;
@@ -173,7 +179,7 @@ Email::Simple::Markdown - simple email creation with auto text and html multipar
 
 =head1 VERSION
 
-version 0.6.0
+version 0.7.0
 
 =head1 SYNOPSIS
 
